"""
This module defines the `ObserveXRuleBase` class, which serves as a base class for creating 
observation rules within the ObserveX library. 

The `ObserveXRuleBase` class is intended to be extended by other classes to implement specific 
rules that apply to different parts of a dataset, such as rows, columns, or metadata. 
"""
from observex.core import base as oxb
class ObserveXRuleBase(oxb.ObserveXGlobalBase):
    """
    Base class for defining observation rules in the ObserveX library.

    Attributes:
    - _rule_applies_to (str or None): A string specifying the area to which the rule applies. 
      For `ObserveXRuleBase`, this is set to None and should be defined in subclasses.
    """
    _rule_applies_to = None

    def __init__(self):
        """
        Initializes the ObserveXRuleBase class.

        Calls the constructor of the base class `ObserveXGlobalBase`. This base class does not 
        implement specific rule logic but provides foundational functionality for derived classes.
        """
        super().__init__()



